==> rocon-1.2.0.tgz: package/esm/builder/RouteRecord/RouteRecordBase.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _classPrivateFieldGet from "@babel/runtime/helpers/esm/classPrivateFieldGet";
import _classPrivateFieldSet from "@babel/runtime/helpers/esm/classPrivateFieldSet";
import { routeRecordParentKey, routeRecordSegmentGetterKey } from "../symbols";
const defaultRoot = {
  pathname: "/",
  state: null
};
/**
 * Object for each route provided by RouteBuilder.
 * Should implement RouteRecordType.
 */

var _builder = new WeakMap();

export class RouteRecordBase {
  /**
   * Action of this route.
   */
  constructor(parentLink, action, segmentGetter) {
    _defineProperty(this, "action", void 0);

    _defineProperty(this, routeRecordParentKey, void 0);

    _builder.set(this, {
      writable: true,
      value: undefined
    });

    _defineProperty(this, routeRecordSegmentGetterKey, void 0);

    _defineProperty(this, "attach", void 0);

    this.action = action;
    this[routeRecordSegmentGetterKey] = segmentGetter;
    Object.defineProperty(this, routeRecordParentKey, {
      value: parentLink
    });
    Object.defineProperty(this, "attach", {
      configurable: true,
      writable: true,

      value(builder) {
        const link = builder.getBuilderLink().getAttachmentRoot();

        _classPrivateFieldSet(this, _builder, link);

        link.attachToParent(parentLink, segmentGetter);
        return builder;
      }

    });
  }
  /**
   * Get the link attached to this Route.
   */


  getAttachedBuilderLink() {
    return _classPrivateFieldGet(this, _builder);
  }
  /**
   * Attach given builder as a child of this route.
   */


}

==> rocon-1.2.6.tgz: package/esm/builder/RouteRecord/RouteRecordBase.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _classPrivateFieldGet from "@babel/runtime/helpers/esm/classPrivateFieldGet";
import _classPrivateFieldSet from "@babel/runtime/helpers/esm/classPrivateFieldSet";

function _classPrivateFieldInitSpec(obj, privateMap, value) { _checkPrivateRedeclaration(obj, privateMap); privateMap.set(obj, value); }

function _checkPrivateRedeclaration(obj, privateCollection) { if (privateCollection.has(obj)) { throw new TypeError("Cannot initialize the same private elements twice on an object"); } }

import { routeRecordParentKey, routeRecordSegmentGetterKey } from "../symbols";
const defaultRoot = {
  pathname: "/",
  state: null
};
/**
 * Object for each route provided by RouteBuilder.
 * Should implement RouteRecordType.
 */

var _builder = /*#__PURE__*/new WeakMap();

export class RouteRecordBase {
  /**
   * Action of this route.
   */
  constructor(parentLink, action, segmentGetter) {
    _defineProperty(this, "action", void 0);

    _defineProperty(this, routeRecordParentKey, void 0);

    _classPrivateFieldInitSpec(this, _builder, {
      writable: true,
      value: undefined
    });

    _defineProperty(this, routeRecordSegmentGetterKey, void 0);

    _defineProperty(this, "attach", void 0);

    this.action = action;
    this[routeRecordSegmentGetterKey] = segmentGetter;
    Object.defineProperty(this, routeRecordParentKey, {
      value: parentLink
    });
    Object.defineProperty(this, "attach", {
      configurable: true,
      writable: true,

      value(builder) {
        const link = builder.getBuilderLink().getAttachmentRoot();

        _classPrivateFieldSet(this, _builder, link);

        link.attachToParent(parentLink, segmentGetter);
        return builder;
      }

    });
  }
  /**
   * Get the link attached to this Route.
   */


  getAttachedBuilderLink() {
    return _classPrivateFieldGet(this, _builder);
  }
  /**
   * Attach given builder as a child of this route.
   */


}
